@@ -1138,6 +1138,26 @@ class AsYouTypeFormatterTest(TestMetadataTestCase):
         self.assertEqual("007001234567890123456", formatter.input_digit('6'))
         self.assertEqual("0070012345678901234567", formatter.input_digit('7'))
 
+    def testAYTFNumberPatternsBecomingInvalidShouldNotResultInDigitLoss(self):
+        formatter = AsYouTypeFormatter("CN")
+        self.assertEqual("+", formatter.input_digit('+'))
+        self.assertEqual("+8", formatter.input_digit('8'))
+        self.assertEqual("+86 ", formatter.input_digit('6'))
+        self.assertEqual("+86 9", formatter.input_digit('9'))
+        self.assertEqual("+86 98", formatter.input_digit('8'))
+        self.assertEqual("+86 988", formatter.input_digit('8'))
+        self.assertEqual("+86 988 1", formatter.input_digit('1'))
+        # Now the number pattern is no longer valid because there are multiple
+        # leading digit patterns; when we try again to extract a country code
+        # we should ensure we use the last leading digit pattern, rather than
+        # the first one such that it *thinks* it's found a valid formatting
+        # rule again.
+        # https://code.google.com/p/libphonenumber/issues/detail?id=437
+        self.assertEqual("+8698812", formatter.input_digit('2'))
+        self.assertEqual("+86988123", formatter.input_digit('3'))
+        self.assertEqual("+869881234", formatter.input_digit('4'))
+        self.assertEqual("+8698812345", formatter.input_digit('5'))
+
     def testAYTFShortNumberFormatting_AR(self):
         # Python version extra test: use real metadata
         formatter = AsYouTypeFormatter("AR")
